@@ -1,31 +1,34 @@
+import asyncio
 import signal
 import sys
-from asyncio import get_event_loop, gather, all_tasks, iscoroutine
+from asyncio import gather, get_event_loop, iscoroutine
 from asyncio.events import AbstractEventLoop
-from typing import Awaitable, Optional, Union, cast, List
+from typing import Any, Awaitable, List, Optional, Set, Union, cast
 
-from aiocli.commander_app import Application, Command, command
+from aiocli.commander_app import Application, Command, Depends, command
 
 __all__ = (
     # commander_app
     'Application',
     'Command',
     'command',
+    'Depends',
     # commander
     'run_app',
 )
 
+from aiocli.helpers import all_tasks
+
 
 class GracefulExit(SystemExit):
-    code = 1
+    code = 0
 
 
 def _raise_graceful_exit() -> None:
     raise GracefulExit()
 
 
-def _cancel_all_tasks(loop: AbstractEventLoop) -> None:
-    to_cancel = all_tasks(loop)
+def _cancel_tasks(to_cancel: Set['asyncio.Task[Any]'], loop: AbstractEventLoop) -> None:
     if not to_cancel:
         return
     for task in to_cancel:
@@ -35,23 +38,25 @@ def _cancel_all_tasks(loop: AbstractEventLoop) -> None:
         if task.cancelled():
             continue
         if task.exception() is not None:
-            loop.call_exception_handler({
-                'message': 'unhandled exception during asyncio.run() shutdown',
-                'exception': task.exception(),
-                'task': task,
-            })
+            loop.call_exception_handler(
+                {
+                    'message': 'unhandled exception during asyncio.run() shutdown',
+                    'exception': task.exception(),
+                    'task': task,
+                }
+            )
 
 
 class AppRunner:
     __slots__ = ('_app', '_loop', '_handle_signals', '_exit_code')
 
     def __init__(
-            self,
-            app: Application,
-            *,
-            loop: Optional[AbstractEventLoop] = None,
-            handle_signals: bool = False,
-            exit_code: bool = False
+        self,
+        app: Application,
+        *,
+        loop: Optional[AbstractEventLoop] = None,
+        handle_signals: bool = False,
+        exit_code: bool = False
     ) -> None:
         self._app = app
         self._loop = loop or get_event_loop()
@@ -89,16 +94,16 @@ class AppRunner:
                 pass
         await self._app.cleanup()
         if self._exit_code:
-            self._app.parser.exit(status=self._app.exit_code)
+            self._app.exit()
 
 
 async def _run_app(
-        app: Union[Application, Awaitable[Application]],
-        *,
-        loop: AbstractEventLoop,
-        handle_signals: bool = True,
-        argv: Optional[List[str]] = None,
-        exit_code: bool = True
+    app: Union[Application, Awaitable[Application]],
+    *,
+    loop: AbstractEventLoop,
+    handle_signals: bool = True,
+    argv: Optional[List[str]] = None,
+    exit_code: bool = True
 ) -> None:
     app = cast(Application, await app if iscoroutine(app) else app)  # type: ignore
     runner = AppRunner(app, loop=loop, handle_signals=handle_signals, exit_code=exit_code)
@@ -110,12 +115,12 @@ async def _run_app(
 
 
 def run_app(
-        app: Union[Application, Awaitable[Application]],
-        *,
-        loop: Optional[AbstractEventLoop] = None,
-        handle_signals: bool = True,
-        argv: Optional[List[str]] = None,
-        exit_code: bool = True
+    app: Union[Application, Awaitable[Application]],
+    *,
+    loop: Optional[AbstractEventLoop] = None,
+    handle_signals: bool = True,
+    argv: Optional[List[str]] = None,
+    exit_code: bool = True
 ) -> None:
     loop = loop or get_event_loop()
     try:
@@ -123,6 +128,6 @@ def run_app(
     except (GracefulExit, KeyboardInterrupt):  # pragma: no cover
         pass
     finally:
-        _cancel_all_tasks(loop)
+        _cancel_tasks(to_cancel=all_tasks(loop=loop), loop=loop)
         loop.run_until_complete(loop.shutdown_asyncgens())
         loop.close()
